        select - extract fields from simple text databases

This is similar in concept to a SQL SELECT statement.  It operates
on simple text database files - each record is one line in the
file, and data items are separated by the designated field separator
character, generally tab.

See the manual entry for more details.

Files in this distribution:

    README		this
    Makefile		guess
    select.c		source file
    select.1		manual entry
    strlist.h		header file for string list package
    strlist.c		source file for string list package
    strtab.h		header file for string table package
    strtab.c		source file for string table package

Feedback is welcome - send bug reports, enhancements, checks, money
orders, etc. to the addresses below.

    Jef Poskanzer  jef@mail.acme.com  http://www.acme.com/jef/
